==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24PropertyListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$PropertyListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 427dcf72b1100411 javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24PropertyListener.h <==
// public class javax.swing.plaf.basic.BasicToolBarUI$PropertyListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9b0f9670da8b886 javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24PropertyListener_H_ */
